@@ -1,23 +1,24 @@
 ####################################################################
 #' Get API (JSON) and Transform into data.frame
-#' 
-#' This function lets the user bring API data as JSON format and transform it 
-#' into data.frame. Designed initially for Hubspot but may work on other API
-#' 
+#'
+#' This function lets the user bring API data as JSON format and
+#' transform it into data.frame.
+#'
 #' @family Tools
 #' @family API
 #' @param url Character. API's URL to GET.
 #' @param status Boolean. Display status message?
-#' @return data.frame of \code{url} GET results or NULL if no results returned by API.
+#' @return data.frame of \code{url} \code{GET} results or
+#' \code{NULL} if no results returned by API.
 #' @export
 bring_api <- function(url, status = TRUE) {
-  
   get <- GET(url = url)
-  if (status) 
-    message(paste0("Status: ", ifelse(get$status_code == 200, "OK", "ERROR"))) 
+  if (status) {
+    message(paste("Status: ", ifelse(get$status_code == 200, "OK", "ERROR")))
+  }
   char <- rawToChar(get$content)
   json <- fromJSON(char)
-  
+
   if (length(json[[1]]) > 0) {
     import <- data.frame(json)
     import <- flatten(import)
@@ -27,5 +28,7 @@ bring_api <- function(url, status = TRUE) {
     colnames(import) <- gsub("\\.", "_", colnames(import))
     import <- suppressMessages(type.convert(import, numerals = "no.loss", as.is = TRUE))
     return(import)
-  } else invisible(return(NULL))
+  } else {
+    invisible(return(NULL))
+  }
 }
